@@ -23,6 +23,7 @@ import string
 from datetime import datetime, timedelta, timezone
 from random import SystemRandom
 from typing import TYPE_CHECKING, Any, Optional
+from urllib.parse import parse_qs, urlparse
 
 import jwt
 import requests
@@ -30,8 +31,18 @@ from lxml import etree
 from requests.auth import AuthBase
 
 from eodag.plugins.authentication import Authentication
-from eodag.utils import HTTP_REQ_TIMEOUT, USER_AGENT, parse_qs, repeatfunc, urlparse
-from eodag.utils.exceptions import AuthenticationError, MisconfiguredError, TimeOutError
+from eodag.utils import (
+    DEFAULT_TOKEN_EXPIRATION_MARGIN,
+    HTTP_REQ_TIMEOUT,
+    USER_AGENT,
+    repeatfunc,
+)
+from eodag.utils.exceptions import (
+    AuthenticationError,
+    MisconfiguredError,
+    RequestError,
+    TimeOutError,
+)
 
 if TYPE_CHECKING:
     from requests import PreparedRequest, Response
@@ -112,13 +123,22 @@ class OIDCRefreshTokenBase(Authentication):
 
     def _get_access_token(self) -> str:
         now = datetime.now(timezone.utc)
-        if self.access_token and now < self.access_token_expiration:
+        expiration_margin = timedelta(
+            seconds=getattr(
+                self.config, "token_expiration_margin", DEFAULT_TOKEN_EXPIRATION_MARGIN
+            )
+        )
+
+        if self.access_token and self.access_token_expiration - now > expiration_margin:
             logger.debug(
                 f"Existing access_token is still valid until {self.access_token_expiration.isoformat()}."
             )
             return self.access_token
 
-        elif self.refresh_token and now < self.refresh_token_expiration:
+        elif (
+            self.refresh_token
+            and self.refresh_token_expiration - now > expiration_margin
+        ):
             response = self._get_token_with_refresh_token()
             logger.debug(
                 "access_token expired, fetching new access_token using refresh_token"
@@ -263,6 +283,8 @@ class OIDCAuthorizationCodeFlowAuth(OIDCRefreshTokenBase):
           Refers to the name of the query param to be used in the query request
         * :attr:`~eodag.config.PluginConfig.refresh_token_key` (``str``): The key pointing to
           the refresh_token in the json response to the POST request to the token server
+        * :attr:`~eodag.config.PluginConfig.token_expiration_margin` (``int``): The margin of time (in seconds)
+          before a token is considered expired. Default: 60 seconds.
 
     """
 
@@ -304,12 +326,17 @@ class OIDCAuthorizationCodeFlowAuth(OIDCRefreshTokenBase):
         state = self.compute_state()
         authentication_response = self.authenticate_user(state)
         exchange_url = authentication_response.url
+
         for err_pattern, err_message in getattr(
             self.config, "exchange_url_error_pattern", {}
         ).items():
             if err_pattern in exchange_url:
                 raise AuthenticationError(err_message)
+
         if not exchange_url.startswith(self.config.redirect_uri):
+            if "Invalid username or password" in authentication_response.text:
+                raise AuthenticationError("Invalid username or password")
+
             raise AuthenticationError(
                 f"Could not authenticate user with provider {self.provider}.",
                 "Please verify your credentials",
@@ -369,13 +396,20 @@ class OIDCAuthorizationCodeFlowAuth(OIDCRefreshTokenBase):
             "redirect_uri": self.config.redirect_uri,
         }
         ssl_verify = getattr(self.config, "ssl_verify", True)
-        authorization_response = self.session.get(
-            self.authorization_endpoint,
-            params=params,
-            headers=USER_AGENT,
-            timeout=HTTP_REQ_TIMEOUT,
-            verify=ssl_verify,
-        )
+        try:
+            authorization_response = self.session.get(
+                self.authorization_endpoint,
+                params=params,
+                headers=USER_AGENT,
+                timeout=HTTP_REQ_TIMEOUT,
+                verify=ssl_verify,
+            )
+        except requests.exceptions.Timeout as exc:
+            raise TimeoutError(exc, "The authentication request timed out.") from exc
+        except requests.RequestException as exc:
+            raise RequestError.from_error(
+                exc, "An error occurred while authenticating the user."
+            ) from exc
 
         login_document = etree.HTML(authorization_response.text)
         login_forms = login_document.xpath(self.config.login_form_xpath)
@@ -413,13 +447,20 @@ class OIDCAuthorizationCodeFlowAuth(OIDCRefreshTokenBase):
             auth_uri = getattr(self.config, "authentication_uri", None)
             if not auth_uri:
                 raise MisconfiguredError("authentication_uri is missing")
-        return self.session.post(
-            auth_uri,
-            data=login_data,
-            headers=USER_AGENT,
-            timeout=HTTP_REQ_TIMEOUT,
-            verify=ssl_verify,
-        )
+        try:
+            return self.session.post(
+                auth_uri,
+                data=login_data,
+                headers=USER_AGENT,
+                timeout=HTTP_REQ_TIMEOUT,
+                verify=ssl_verify,
+            )
+        except requests.exceptions.Timeout as exc:
+            raise TimeoutError(exc, "The authentication request timed out.") from exc
+        except requests.RequestException as exc:
+            raise RequestError.from_error(
+                exc, "An error occurred while authenticating the user."
+            ) from exc
 
     def grant_user_consent(self, authentication_response: Response) -> Response:
         """Grant user consent"""
@@ -433,13 +474,20 @@ class OIDCAuthorizationCodeFlowAuth(OIDCRefreshTokenBase):
             for key, value in self.config.user_consent_form_data.items()
         }
         ssl_verify = getattr(self.config, "ssl_verify", True)
-        return self.session.post(
-            self.authorization_endpoint,
-            data=user_consent_data,
-            headers=USER_AGENT,
-            timeout=HTTP_REQ_TIMEOUT,
-            verify=ssl_verify,
-        )
+        try:
+            return self.session.post(
+                self.authorization_endpoint,
+                data=user_consent_data,
+                headers=USER_AGENT,
+                timeout=HTTP_REQ_TIMEOUT,
+                verify=ssl_verify,
+            )
+        except requests.exceptions.Timeout as exc:
+            raise TimeoutError(exc, "The authentication request timed out.") from exc
+        except requests.RequestException as exc:
+            raise RequestError.from_error(
+                exc, "An error occurred while authenticating the user."
+            ) from exc
 
     def _prepare_token_post_data(self, token_data: dict[str, Any]) -> dict[str, Any]:
         """Prepare the common data to post to the token URI"""
@@ -487,14 +535,21 @@ class OIDCAuthorizationCodeFlowAuth(OIDCRefreshTokenBase):
             self.config.token_exchange_post_data_method: token_exchange_data
         }
         ssl_verify = getattr(self.config, "ssl_verify", True)
-        r = self.session.post(
-            self.token_endpoint,
-            headers=USER_AGENT,
-            timeout=HTTP_REQ_TIMEOUT,
-            verify=ssl_verify,
-            **post_request_kwargs,
-        )
-        return r
+        try:
+            r = self.session.post(
+                self.token_endpoint,
+                headers=USER_AGENT,
+                timeout=HTTP_REQ_TIMEOUT,
+                verify=ssl_verify,
+                **post_request_kwargs,
+            )
+            return r
+        except requests.exceptions.Timeout as exc:
+            raise TimeoutError(exc, "The authentication request timed out.") from exc
+        except requests.RequestException as exc:
+            raise RequestError.from_error(
+                exc, "An error occurred while authenticating the user."
+            ) from exc
 
     def _constant_or_xpath_extracted(
         self, value: str, form_element: Any
