@@ -57,10 +57,16 @@ from eodag.utils import (
     DEFAULT_SEARCH_TIMEOUT,
     deepcopy,
     dict_items_recursive_sort,
+    get_geometry_from_ecmwf_area,
+    get_geometry_from_ecmwf_feature,
     get_geometry_from_various,
 )
 from eodag.utils.cache import instance_cached_method
-from eodag.utils.dates import is_range_in_range
+from eodag.utils.dates import (
+    COMPACT_DATE_RANGE_PATTERN,
+    DATE_RANGE_PATTERN,
+    is_range_in_range,
+)
 from eodag.utils.exceptions import DownloadError, NotAvailableError, ValidationError
 from eodag.utils.requests import fetch_json
 
@@ -145,6 +151,7 @@ COP_DS_KEYWORDS = {
     "aerosol_type",
     "altitude",
     "product_type",
+    "area",
     "band",
     "cdr_type",
     "data_format",
@@ -182,6 +189,7 @@ COP_DS_KEYWORDS = {
     "region",
     "release_version",
     "satellite",
+    "satellite_mission",
     "sensor",
     "sensor_and_algorithm",
     "soil_level",
@@ -189,6 +197,7 @@ COP_DS_KEYWORDS = {
     "statistic",
     "system_version",
     "temporal_aggregation",
+    "temporal_resolution",
     "time_aggregation",
     "time_reference",
     "time_step",
@@ -607,6 +616,14 @@ class ECMWFSearch(PostJsonSearch):
         # geometry
         if "geometry" in params:
             params["geometry"] = get_geometry_from_various(geometry=params["geometry"])
+        # ECMWF Polytope uses non-geojson structure for features
+        if "feature" in params:
+            params["geometry"] = get_geometry_from_ecmwf_feature(params["feature"])
+            params.pop("feature")
+        # bounding box in area format
+        if "area" in params:
+            params["geometry"] = get_geometry_from_ecmwf_area(params["area"])
+            params.pop("area")
 
         return params
 
@@ -696,10 +713,13 @@ class ECMWFSearch(PostJsonSearch):
         if "end" in filters:
             filters[END] = filters.pop("end")
 
-        # extract default datetime
-        processed_filters = self._preprocess_search_params(
-            deepcopy(filters), product_type
-        )
+        # extract default datetime and convert geometry
+        try:
+            processed_filters = self._preprocess_search_params(
+                deepcopy(filters), product_type
+            )
+        except Exception as e:
+            raise ValidationError(e.args[0]) from e
 
         constraints_url = format_metadata(
             getattr(self.config, "discover_queryables", {}).get("constraints_url", ""),
@@ -714,7 +734,7 @@ class ECMWFSearch(PostJsonSearch):
         form: list[dict[str, Any]] = self._fetch_data(form_url)
 
         formated_filters = self.format_as_provider_keyword(
-            product_type, processed_filters
+            product_type, deepcopy(processed_filters)
         )
         # we re-apply kwargs input to consider override of year, month, day and time.
         for k, v in {**default_values, **kwargs}.items():
@@ -723,7 +743,6 @@ class ECMWFSearch(PostJsonSearch):
             if key not in ALLOWED_KEYWORDS | {
                 START,
                 END,
-                "geom",
                 "geometry",
             }:
                 raise ValidationError(
@@ -772,7 +791,7 @@ class ECMWFSearch(PostJsonSearch):
         # To check if all keywords are queryable parameters, we check if they are in the
         # available values or the product type config (available values calculated from the
         # constraints might not include all queryables)
-        for keyword in filters:
+        for keyword in processed_filters:
             if (
                 keyword
                 not in available_values.keys()
@@ -780,7 +799,7 @@ class ECMWFSearch(PostJsonSearch):
                 | {
                     START,
                     END,
-                    "geom",
+                    "geometry",
                 }
                 and keyword not in [f["name"] for f in form]
                 and keyword.removeprefix(ECMWF_PREFIX)
@@ -880,13 +899,21 @@ class ECMWFSearch(PostJsonSearch):
                 )
 
             # We convert every single value to a list of string
-            filter_v = values if isinstance(values, (list, tuple)) else [values]
+            filter_v = list(values) if isinstance(values, tuple) else values
+            filter_v = filter_v if isinstance(filter_v, list) else [filter_v]
 
             # We strip values of superfluous quotes (added by mapping converter to_geojson).
-            # ECMWF accept values with /to/. We need to split it to an array
-            # ECMWF accept values in format val1/val2. We need to split it to an array
-            sep = re.compile(r"/to/|/")
-            filter_v = [i for v in filter_v for i in sep.split(str(v))]
+            # ECMWF accept date ranges with /to/. We need to split it to an array
+            # ECMWF accept date ranges in format val1/val2. We need to split it to an array
+            date_regex = [
+                re.compile(p) for p in (DATE_RANGE_PATTERN, COMPACT_DATE_RANGE_PATTERN)
+            ]
+            is_date = any(
+                any(r.match(v) is not None for r in date_regex) for v in filter_v
+            )
+            if is_date:
+                sep = re.compile(r"/to/|/")
+                filter_v = [i for v in filter_v for i in sep.split(str(v))]
 
             # special handling for time 0000 converted to 0 by pre-formating with metadata_mapping
             if keyword.split(":")[-1] == "time":
