@@ -211,9 +211,12 @@ class CopMarineSearch(StaticStacSearch):
         dataset_item: dict[str, Any],
         collection_dict: dict[str, Any],
         use_dataset_dates: bool = False,
+        product_id: Optional[str] = None,
     ) -> Optional[EOProduct]:
 
         item_id = os.path.splitext(item_key.split("/")[-1])[0]
+        if product_id and product_id != item_id:
+            return None
         download_url = s3_url + "/" + item_key
         geometry = (
             get_geometry_from_various(**dataset_item)
@@ -377,9 +380,12 @@ class CopMarineSearch(StaticStacSearch):
                         dataset_item,
                         collection_dict,
                         True,
+                        kwargs.get("id"),
                     )
                     if product:
                         products.append(product)
+                    if product and kwargs.get("id"):
+                        break
                     continue
 
             s3_client = _get_s3_client(endpoint_url)
