@@ -77,7 +77,7 @@ from jsonpath_ng import jsonpath
 from jsonpath_ng.ext import parse
 from jsonpath_ng.jsonpath import Child, Fields, Index, Root, Slice
 from requests import HTTPError, Response
-from shapely.geometry import Polygon, shape
+from shapely.geometry import Polygon, box, shape
 from shapely.geometry.base import GEOMETRY_TYPES, BaseGeometry
 from tqdm.auto import tqdm
 
@@ -132,6 +132,9 @@ DEFAULT_MAX_ITEMS_PER_PAGE = 50
 # default product-types start date
 DEFAULT_MISSION_START_DATE = "2015-01-01T00:00:00.000Z"
 
+# default geometry / whole world bounding box
+DEFAULT_SHAPELY_GEOMETRY = box(-180, -90, 180, 90)
+
 # default token expiration margin in seconds
 DEFAULT_TOKEN_EXPIRATION_MARGIN = 60
 
@@ -1052,7 +1055,7 @@ def nested_pairs2dict(pairs: Union[list[Any], Any]) -> Union[Any, dict[Any, Any]
 
 def get_geometry_from_various(
     locations_config: list[dict[str, Any]] = [], **query_args: Any
-) -> BaseGeometry:
+) -> Optional[BaseGeometry]:
     """Creates a ``shapely.geometry`` using given query kwargs arguments
 
     :param locations_config: (optional) EODAG locations configuration
@@ -1137,6 +1140,45 @@ def get_geometry_from_various(
     return geom
 
 
+def get_geometry_from_ecmwf_feature(geom: dict[str, Any]) -> BaseGeometry:
+    """
+    Creates a ``shapely.geometry`` from ECMWF Polytope shape.
+
+    :param geom: ECMWF Polytope shape.
+    :returns: A Shapely polygon.
+    """
+    if not isinstance(geom, dict):
+        raise TypeError(
+            "Geometry must be a dictionary, instead it's {}".format(type(geom))
+        )
+    if "type" not in geom or geom["type"] != "polygon":
+        raise TypeError("Geometry type must be 'polygon'")
+    if "shape" not in geom:
+        raise TypeError("Missing shape in the geometry")
+    if not isinstance(geom["shape"], list):
+        raise TypeError("Geometry shape must be a list")
+
+    shape: list = geom["shape"]
+    polygon_args = [(p[1], p[0]) for p in shape]
+    return Polygon(polygon_args)
+
+
+def get_geometry_from_ecmwf_area(area: list[float]) -> Optional[BaseGeometry]:
+    """
+    Creates a ``shapely.geometry`` from bounding box in area format.
+
+    area format: [max_lat,min_lon,min_lat,max_lon]
+
+    :param area: bounding box in area format.
+    :returns: A Shapely polygon.
+    """
+    if len(area) != 4:
+        raise ValueError("The area must be a list of 4 values")
+    max_lat, min_lon, min_lat, max_lon = area
+    bbox = [min_lon, min_lat, max_lon, max_lat]
+    return get_geometry_from_various(geometry=bbox)
+
+
 class MockResponse:
     """Fake requests response"""
 
