@@ -272,6 +272,17 @@ class TestConfigFunctions(unittest.TestCase):
             else:
                 self.assertEqual(value.priority, 0)
 
+    def test_load_config_providers_whitelist(self):
+        """Config must be loaded with only the selected whitelist of providers"""
+        try:
+            os.environ["EODAG_PROVIDERS_WHITELIST"] = "creodias"
+            conf = config.load_default_config()
+
+            self.assertIsInstance(conf, dict)
+            self.assertEqual({"creodias"}, set(conf.keys()))
+        finally:
+            os.environ.pop("EODAG_PROVIDERS_WHITELIST", None)
+
     def test_override_config_from_str(self):
         """Default configuration must be overridden from a yaml conf str"""
         default_config = config.load_default_config()
@@ -338,10 +349,6 @@ class TestConfigFunctions(unittest.TestCase):
           download:
               output_dir: /data
 
-        theia:
-            download:
-                output_dir:
-
         my_new_provider:
             priority: 4
             search:
@@ -388,9 +395,6 @@ class TestConfigFunctions(unittest.TestCase):
         peps_conf = default_config["peps"]
         self.assertEqual(peps_conf.download.output_dir, "/data")
 
-        theia_conf = default_config["theia"]
-        self.assertEqual(theia_conf.download.output_dir, tempfile.gettempdir())
-
         my_new_provider_conf = default_config["my_new_provider"]
         self.assertEqual(my_new_provider_conf.priority, 4)
         self.assertIsInstance(my_new_provider_conf.search, config.PluginConfig)
@@ -431,12 +435,12 @@ class TestConfigFunctions(unittest.TestCase):
         os.environ["EODAG__USGS__API__CREDENTIALS__USERNAME"] = "usr"
         os.environ["EODAG__USGS__API__CREDENTIALS__PASSWORD"] = "pwd"
         os.environ["EODAG__AWS_EOS__SEARCH__PRODUCT_LOCATION_SCHEME"] = "file"
-        os.environ["EODAG__AWS_EOS__AUTH__CREDENTIALS__APIKEY"] = "api-key"
+        os.environ["EODAG__AWS_EOS__SEARCH_AUTH__CREDENTIALS__APIKEY"] = "api-key"
         os.environ[
-            "EODAG__AWS_EOS__AUTH__CREDENTIALS__AWS_ACCESS_KEY_ID"
+            "EODAG__AWS_EOS__DOWNLOAD_AUTH__CREDENTIALS__AWS_ACCESS_KEY_ID"
         ] = "access-key-id"
         os.environ[
-            "EODAG__AWS_EOS__AUTH__CREDENTIALS__AWS_SECRET_ACCESS_KEY"
+            "EODAG__AWS_EOS__DOWNLOAD_AUTH__CREDENTIALS__AWS_SECRET_ACCESS_KEY"
         ] = "secret-access-key"
         os.environ["EODAG__PEPS__DOWNLOAD__OUTPUT_DIR"] = "/data"
         # check a parameter that has not been set yet
@@ -454,12 +458,13 @@ class TestConfigFunctions(unittest.TestCase):
 
         aws_conf = default_config["aws_eos"]
         self.assertEqual(aws_conf.search.product_location_scheme, "file")
-        self.assertEqual(aws_conf.auth.credentials["apikey"], "api-key")
+        self.assertEqual(aws_conf.search_auth.credentials["apikey"], "api-key")
         self.assertEqual(
-            aws_conf.auth.credentials["aws_access_key_id"], "access-key-id"
+            aws_conf.download_auth.credentials["aws_access_key_id"], "access-key-id"
         )
         self.assertEqual(
-            aws_conf.auth.credentials["aws_secret_access_key"], "secret-access-key"
+            aws_conf.download_auth.credentials["aws_secret_access_key"],
+            "secret-access-key",
         )
 
         peps_conf = default_config["peps"]
